==> tuia-treasure-center-api-0.0.11_5-20180723.025008-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleContentDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/4/23.
 */
public class ArticleContentDto implements Serializable {


    private static final long serialVersionUID = -60903987601298769L;
    /**
     * id
     */
    private Long id;
    /**
     * 内容标题
     */
    private  String title;


    /**
     * 内容链接地址
     */
    private String url;


    /**
     * 缩略图地址
     */
    private String  headImgUrl;

    /**
     * 文章作者Id
     */
    private Long accountId;

    /**
     * 评论数
     */
    private Long commentNumber;

    /**
     * 发布日期
     * @return
     */
    private Date gmtPublish;
    /**
     * 文章来源
     */
    private Integer articleSource;


    public Integer getArticleSource() {
        return articleSource;
    }

    public void setArticleSource(Integer articleSource) {
        this.articleSource = articleSource;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getCommentNumber() {
        return commentNumber;
    }

    public void setCommentNumber(Long commentNumber) {
        this.commentNumber = commentNumber;
    }

    public Date getGmtPublish() {
        return gmtPublish;
    }

    public void setGmtPublish(Date gmtPublish) {
        this.gmtPublish = gmtPublish;
    }
}

==> tuia-treasure-center-api-0.0.11-20180720.015515-4-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleContentDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/4/23.
 */
public class ArticleContentDto implements Serializable {


    private static final long serialVersionUID = -60903987601298769L;
    /**
     * id
     */
    private Long id;
    /**
     * 内容标题
     */
    private  String title;


    /**
     * 内容链接地址
     */
    private String url;


    /**
     * 缩略图地址
     */
    private String  headImgUrl;

    /**
     * 文章作者Id
     */
    private Long accountId;

    /**
     * 评论数
     */
    private Long commentNumber;

    /**
     * 发布日期
     * @return
     */
    private Date gmtPublish;
    /**
     * 文章来源
     */
    private Integer articleStatus;


    public Integer getArticleStatus() {
        return articleStatus;
    }

    public void setArticleStatus(Integer articleStatus) {
        this.articleStatus = articleStatus;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getCommentNumber() {
        return commentNumber;
    }

    public void setCommentNumber(Long commentNumber) {
        this.commentNumber = commentNumber;
    }

    public Date getGmtPublish() {
        return gmtPublish;
    }

    public void setGmtPublish(Date gmtPublish) {
        this.gmtPublish = gmtPublish;
    }
}
